//
//  TitleLayer.m
//  Game01
//
//  Created by Kansuke Nishida on 11/09/18.
//  Copyright 2011年 tonosamart. All rights reserved.
//

#import "GameScene.h"
#import "SimpleAudioEngine.h"
#import "TitleLayer.h"
#import "Constants.h"

@interface TitleLayer (private)
-(void)initLayer;
-(void)tick:(ccTime)dt;
-(void)delSprite:(id)node;
@end

@implementation TitleLayer

enum {
    SPRITE_NULL,
    SPRITE_PARTICLE,
    SPRITE_PLAYER,
    SPRITE_TEXT,
    SPRITE_MENU
};

- (id)init{
    self = [super init];
    if (self) {
        // イベントの無効/有効
        self.isTouchEnabled = YES;
        self.isAccelerometerEnabled = NO;
        
        //レイヤーの初期化
        [self initLayer];
    }
    
    return self;
}

#pragma mark private

-(void)initLayer{
    CCSprite* sprite = [CCSprite spriteWithFile:@"free03_179.png"];
    sprite.position = ccp(240, 160);
    [self addChild:sprite z:SPRITE_PLAYER tag:SPRITE_PLAYER];

    //---
    CCLabelTTF* label = [CCLabelTTF labelWithString:@"" fontName:@"Marker Felt" fontSize:32];
    label.color = ccc3(255, 0, 0);
    label.position = ccp(240, 240);
    [self addChild:label z:SPRITE_TEXT tag:SPRITE_TEXT]; 
    
    //---
    [[SimpleAudioEngine sharedEngine] preloadEffect:@"coin.caf"];
    
    //---
    
    CCParticleSystem* system = [CCParticleGalaxy node];
    [self addChild: system z:SPRITE_PARTICLE tag:SPRITE_PARTICLE];
    
    //---
    srand(time(nil));
    
    [self schedule:@selector(tick:)];
}

-(void)tick:(ccTime)dt{
    Stick* stick = [Stick stick];
    
    CCSprite* sprite = (CCSprite*)[self getChildByTag:SPRITE_PLAYER];
    sprite.position = ccp(sprite.position.x + (stick.x * 100 * dt), sprite.position.y + (stick.y * 100 * dt));

    CCParticleSystem* system = (CCParticleSystem*)[self getChildByTag:SPRITE_PARTICLE];
    
    if(stick.isA){
        [self removeChildByTag:SPRITE_PARTICLE cleanup:YES];
        system = [CCParticleGalaxy node];
        [self addChild: system z:SPRITE_PARTICLE tag:SPRITE_PARTICLE];
    }
    if(stick.isB){
        [self removeChildByTag:SPRITE_PARTICLE cleanup:YES];
        system = [CCParticleSnow node];
        [self addChild: system z:SPRITE_PARTICLE tag:SPRITE_PARTICLE];
    }
    if(stick.isC){
        [self removeChildByTag:SPRITE_PARTICLE cleanup:YES];
        system = [CCParticleSystemQuad particleWithFile:@"blue_warp.plist"];
        [self addChild: system z:SPRITE_PARTICLE tag:SPRITE_PARTICLE];
    }
}

#pragma mark EVENT

-(void)ccTouchesBegan:(NSSet *)touches withEvent:(UIEvent *)event {
	for(UITouch* touch in touches){
		CGPoint touchPoint = [touch locationInView:[touch view]];
		touchPoint = [[CCDirector sharedDirector] convertToGL:touchPoint];
		
		if(CGRectContainsPoint([Constants rectForSprite:(CCSprite*)[self getChildByTag:SPRITE_PLAYER]], touchPoint)){
            [[SimpleAudioEngine sharedEngine] playEffect:@"coin.caf"];
		}
	}
}

-(void)ccTouchesMoved:(NSSet *)touches withEvent:(UIEvent *)event {
}

-(void)ccTouchesEnded:(NSSet *)touches withEvent:(UIEvent *)event {
}

-(void)ccTouchesCancelled:(NSSet *)touches withEvent:(UIEvent *)event {
}

@end

